import { Component } from 'react'
import { View, Text, Image } from '@tarojs/components'
import './index.less'
import wallet from '../../../images/wallet.png'
import { get_withdraw_record } from '../../../service/money_api'

export default class Index extends Component {
  state = {
    withdraw_record_list: [],
    page: 1,
    page_size: 20, // 每页加载20条
    total: 0,
    loading: false // 加载状态
  }

  componentDidShow () {
    this.get_withdraw_record()
  }

  get_withdraw_record = async () => {
    if (this.state.loading) return; // 防止重复加载
    this.setState({ loading: true });
    const res = await get_withdraw_record({
      page: this.state.page,
      page_size: this.state.page_size
    })
    console.log(res, 'res')
    this.setState(prevState => ({
      withdraw_record_list: prevState.page === 1 ? res : [...prevState.withdraw_record_list, ...res],
      loading: false
    }))
  }

  onReachBottom = () => {
    if (this.state.withdraw_record_list.length < this.state.total) {
      this.setState(prevState => ({ page: prevState.page + 1 }), this.get_withdraw_record)
    }
  }

  render () {
    return (
      <View className='index' onScrollToLower={this.onReachBottom}>
        {/* 提现记录 */}
        <View className='cash-out-record'>
          {/* 累计提现金额 */}
          <View className='total-amount'>
            <View className='left'>
              <Image src={wallet} className='icon' />
              <Text className='title'>累计提现金额</Text>
            </View>
            <View className='amount'>
              <Text className='integer'>￥10000.</Text>
              <Text className='decimal'>00</Text>
            </View>
          </View>
          {/* 提现记录 */}
          {this.state.withdraw_record_list.map((item, index) => {
            return (
              <View className='record-item' key={index}>
                <View className='item-time'>{item.time.replace('T', ' ')}</View>
                <View className='item-amount'>
                  <View className='amount'>￥{item.amount}</View>
                  <View className='status'>{item.msg}</View>
                </View>
              </View>
            )
          })}
        </View>
      </View>
    )
  }
}
