import { Component } from "react";
import Taro from "@tarojs/taro";
import { View, Text, Image } from "@tarojs/components";
import { AtList, AtListItem } from "taro-ui";
import { getUserInfo } from "../../service";
import "./index.less";
import loginOut from "../../images/mine/loginOut.png";
import edit from "../../images/mine/edit.png";
import norm from "../../images/mine/norm.png";
import avatar from "../../images/mine/avatar.png";
import sign from "../../images/mine/sign.png";
import SignModal from "../../components/signModal";
import levelOne from "../../images/mine/levelOne.png";
import levelTwo from "../../images/mine/levelTwo.png";
import levelThree from "../../images/mine/levelThree.png";
import levelFour from "../../images/mine/levelFour.png";
import levelFive from "../../images/mine/levelFive.png";
export default class Index extends Component {
  state = {
    userInfo: {}, //用户信息
    isOpened: false, //是否打开弹窗
  };
  // 退出登录
  handleLogout = () => {
    Taro.showModal({
      title: "",
      content: "退出后，请重新登录!",
      cancelText: "暂不退出",
      confirmText: "退出登录",
      cancelColor: "#000000",
      confirmColor: "#F6C71A",
      success: function (res) {
        if (res.confirm) {
          Taro.removeStorageSync("session_key");
          Taro.removeStorageSync("loginInfo");
          Taro.removeStorageSync("userInfo");
          console.log("用户点击退出登录");
        }
      },
    });
  };
  componentDidShow() {
    const session_key = Taro.getStorageSync("session_key");
    if (session_key) {
      this.getUserInfo();
    }
  }
  // 获取用户信息
  getUserInfo = async () => {
    const res = await getUserInfo();
    Taro.setStorageSync("userInfo", res);
    this.setState({
      userInfo: res,
    });
  };
  // 去登录
  Login = () => {
    if (!Taro.getStorageSync("session_key")) {
      Taro.reLaunch({
        url: "/pages/login/index",
      });
    }
  };
  // 合作签约
  handleSign = () => {
    let session_key = Taro.getStorageSync("session_key");
    if (session_key && this.state.userInfo.user_identity === 0) {
      this.setState({
        isOpened: true,
      });
    } else {
      Taro.showToast({
        title: "您已签约",
        icon: "none",
      });
    }
  };
  render() {
    const { userInfo, isOpened } = this.state;
    return (
      <View className="index">
        {/* 个人信息 */}
        <View className="info">
          <Image
            src={userInfo.icon ? userInfo.icon : avatar}
            className="avatar"
          />
          <View className="info-right">
            <View className="user-info">
              <View onClick={this.Login} className="name">
                {userInfo.name ? userInfo.name : "去登录"}
                {/* {userInfo.user_identity === 1 && (
                  <View className="level-box">
                    <Image src={levelOne} className="level-icon" />
                    <Text className="level-text">Lv 1</Text>
                  </View>
                )} */}
              </View>
              <View className="account">{userInfo.id ? userInfo.id : ""}</View>
            </View>
            <Image
              onClick={() =>
                Taro.navigateTo({ url: `/pages/mineSub/infoEdit/index` })
              }
              className="edit-icon"
              src={edit}
            ></Image>
          </View>
        </View>
        {/* 功能 */}
        <View className="function">
          <AtList hasBorder={false}>
            <AtListItem
              hasBorder={false}
              onClick={this.handleSign}
              title="合作签约"
              arrow="right"
              thumb={sign}
            />
            <AtListItem
              hasBorder={false}
              onClick={() =>
                Taro.navigateTo({
                  url: `/pages/mineSub/userSpecification/index`,
                })
              }
              title="用户规范"
              arrow="right"
              thumb={norm}
            />
            {/* <View className="line"></View> */}
            {/* <AtListItem
              hasBorder={false}
              title="退出登录"
              arrow="right"
              thumb={loginOut}
              onClick={this.handleLogout}
            /> */}
          </AtList>
        </View>
        {/* 签约弹窗 */}
        <SignModal
          isMine={true}
          isOpened={isOpened}
          onClose={() => this.setState({ isOpened: false })}
        />
      </View>
    );
  }
}
